@@ -47,6 +47,8 @@ async def process_authorization(request: Request, call_next):
     return response
 
 # Exception异常
+
+
 @app.exception_handler(Exception)
 async def exception_handler(request: Request, e: Exception):
     # logger.bind(request=request, exception=e).error('异常')
@@ -60,9 +62,10 @@ async def exception_handler(request: Request, e: Exception):
     )
     # 处理完后，无法返回@app.middleware("http")，因此这里要自己写日志
     # 访问日志
-    logger.bind(access=True).error(f"{request.method} {request.url}     {result.errid}")
+    logger.bind(access=True).error(
+        f"{request.method} {request.url}     {result.errid}")
 
-    #错误日志
+    # 错误日志
     logger.error(f"1111\nHeaders:{request.headers}\n{traceback.format_exc()}")
 
     return MyResponseError(result)
